# MDU SNPIT
_a self-build tool doing the same job as snpit_

## installation:
```
git clone https://github.com/MDU-PHL/mdu-snpit.git
pip3 install mdu-snpit/dist/*.whl
```

## instruction:
```
mdu-snpit xx.fa
mdu-snpit xx.vcf
mdu-snpit xx/snps.tab
```

## contact:
*josh.zhang@unimelb.edu.au*
